Getting Started
---------------

We advise new users start by reading the :doc:`Architecture <architecture>`
documentation first in order to understand Kayobe's various components.

For users wishing to learn interactively we recommend starting at either
the :doc:`all-in-one overcloud <contributor/automated>` deployment or
the :ref:`'A Universe From Nothing' <a-universe-from-nothing>`
deployment guide.

Once familiar with Kayobe's constituent parts, move on to the
:doc:`Installation <installation>` section to prepare a baremetal environment
and then :doc:`Deployment <deployment>` to deploy to it.

* :doc:`Architecture <architecture>` - The function of Kayobe's host and
  networking components
* :doc:`Installation <installation>` - The prerequisites and options for
  installing Kayobe
* :doc:`Usage <usage>` - An introduction to the Kayobe CLI
* :doc:`Configuration <configuration/index>` - How to configure Kayobe's
  various components
* :doc:`Deployment <deployment>`- Using Kayobe to deploy OpenStack
* :doc:`Upgrading <upgrading>` - Upgrading from one OpenStack release to
  another
* :doc:`Administration <administration/index>` - Post-deploy administration
  tasks
* :doc:`Resources <resources>` - External links to Kayobe resources
* :doc:`Contributor <contributor/index>` - Contributing to Kayobe and deploying
  Kayobe development environments
